# IBM BLUE UTILITIES

### Project description.
This package help to management of bluegroups and retrieve basic information of bluepages. You can retrieve information of bluepages or bluegroups only with your uid and password in some cases your email is needed.